@@ -1,11 +1,12 @@
 ﻿
 
 
-__version__ = "0.2021.3.17.1"
+__version__ = "0.2021.3.19"
 
 
 
 from .FileTypeInfo import FileTypeInfo
+from .do.AbstractDataObjectBase import AbstractDataObjectBase
 from .do._CommonDataObjectMixin import _CommonDataObjectMixin
 from .do.DiskFile import DiskFile
 from .do.InMemoryFile import InMemoryFile
@@ -21,7 +22,6 @@ from .processors_core import core
 
 from .EnumAction import EnumAction
 from._INode import _INode
-from ._ChainNode import _ChainNode
+from ._ChainNodeP import _ChainNodeP
 from ._Sequence import _Sequence
 from ._Chain import _Chain
-
