@@ -1,8 +1,11 @@
 ﻿
 
-__version__ = "0.2021.3.17.1"
+__version__ = "0.2021.3.19"
 
 
 
+from .TreeHelper import TreeHelper
 from .RelFilePathBuilder import RelFilePathBuilder
-from .ObservableEvent import ObservableEvent
\ No newline at end of file
+from .ObservableEvent import ObservableEvent
+from .Color import Color
+
